@@ -2,17 +2,17 @@
 
 # Build zipfiles for Pango on Win32: separate runtime and developer packages
 
-ZIP=/tmp/pango-0.22-`date +%Y%m%d`.zip
-DEVZIP=/tmp/pango-dev-0.22-`date +%Y%m%d`.zip
-cd /usr
+ZIP=/tmp/pango-0.25-`date +%Y%m%d`.zip
+DEVZIP=/tmp/pango-dev-0.25-`date +%Y%m%d`.zip
+cd /opt/gnome2
 
 rm $ZIP
 zip -r $ZIP -@ <<EOF
 bin/pango-querymodules.exe
 etc/pango
-lib/libpango-0-22.dll
-lib/libpangoft2-0-22.dll
-lib/libpangowin32-0-22.dll
+lib/libpango-0-25.dll
+lib/libpangoft2-0-25.dll
+lib/libpangowin32-0-25.dll
 EOF
 
 zip $ZIP lib/pango/modules/*.dll
